@@ -2,18 +2,23 @@ module Development.Shake.FileDetect
     ( getAts
     , getSats
     , getHats
+    , getCats
     , getYml
     , getToml
     , getHs
     , getHappy
     , getAlex
     , getShell
+    , getDhall
     ) where
 
 import           Control.Composition
 import           Data.Semigroup      ((<>))
 import           Development.Shake
 
+getDhall :: Action [FilePath]
+getDhall = getAll ["dhall"]
+
 getYml :: Action [FilePath]
 getYml = getAll ["yaml", "yml", "yamllint"]
 
@@ -41,6 +46,9 @@ getAll = getAllDir ""
 getAllDir :: FilePath -> [String] -> Action [FilePath]
 getAllDir dir ss = getDirectoryFiles "" (((dir ++ "//*.") ++) <$> ss)
 
+getCats :: Action [FilePath]
+getCats = get "cats"
+
 getSats :: Action [FilePath]
 getSats = get "sats"
 
@@ -50,5 +58,6 @@ getDats = get "dats"
 getHats :: Action [FilePath]
 getHats = get "hats"
 
+-- | Get files ending in @.sats@ or @.dats@.
 getAts :: Action [FilePath]
 getAts = (<>) <$> getDats <*> getSats
